@@ -5,7 +5,8 @@
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ *  (at your option) any later version, or (at your opinion) under the terms 
+ *  of the Mozilla Public License version 2.0.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -353,6 +354,25 @@ mod tests {
         assert_eq!(["f", "g", "h", "a"], pq.into_sorted_vec().as_slice());
     }
 
+    #[test]
+    fn remove2() {
+	use std::collections::hash_map::RandomState;
+	let mut queue = PriorityQueue::<i32, i32, RandomState>::default();
+
+	for i in 0..7 {
+            queue.push(i, i);
+	}
+
+	queue.remove(&0);
+
+	let mut last_priority = *queue.peek().unwrap().1;
+	while let Some((_, priority)) = queue.pop() {
+            dbg!(priority);
+            assert!(last_priority >= priority);
+            last_priority = priority;
+	}
+    }
+
     #[test]
     fn extend() {
         let mut pq = PriorityQueue::new();
